---
toc: false
---

# API documentation

::: arvi.timeseries.RV
    handler: python
    options:
        show_root_heading: true
        show_source: false
        merge_init_into_class: false
        group_by_category: true


## Other packages

The following are mostly internal packages with which a user may not need to
interact directly.

??? example "`simbad` API"

    ::: arvi.simbad_wrapper.simbad
        handler: python
        options:
            show_root_heading: true
            show_source: false
            merge_init_into_class: true


??? example "`arvi.stats` API"

    ::: arvi.stats
        handler: python
        options:
            show_root_heading: true
            show_source: false
